*******************************************************************************
*Decompose predicted income inequality for 18 to 55 year old males into 
*between country and within country components. 
*******************************************************************************

capture log close
clear
set mem 18000000
global thedir = "INSERT DIRECTORY FOR FINAL DATA OUTPUT HERE"
global aejfinalcode = "INSERT DIRECTORY CONTAINING DATA INPUTS HERE"
cd $aejfinalcode
log using aej_dcxb, replace

/*Data files used as inputs:
			temp_decompintl.dta
			temp_decompint2.dta (both are produced by aej_dcysmall.do)
Final data files produced (will be inputs into the Matlab file aej_inequality.m)
			aej_dcxbeq (decompositions using equal population weights)
			aej_dcxbact (decompositions using actual population weights)
*/


/* ***---Note: You must download and install the Stata add-on module
	ineqdeco to run this file. Type ssc install ineqdeco from the Stata command
	line or see http://ideas.repec.org/c/boc/bocode/s366002.html
	
	Stephen P. Jenkins, 1999. "INEQDECO: Stata module to calculate inequality indices with 
	decomposition by subgroup,"  Statistical Software Components S366002, Boston College 
	Department of Economics, revised 26 May 2008.
*/

/* ***---Note: This file decomposes predicted income inequality in the 
		Americas into inequality across countries and inequality within countries. 
		The output of this file is used as input into the Matlab file inequality.m, which further 
		decomposes total inequality into cross-country, cross-municipality, and 
		within-municipality inequality.  The file aej_dcysmall.do should be run first.
*/

**********************************
**----Equal Population Weights
**********************************


**--Calculate inequality across all countries

use temp_decompintl, clear

ineqdeco xb [aw=ww], bygroup(ccnum)
gen geb0_aeq=r(between_ge0)
gen gew0_aeq=r(within_ge0)
gen get0_aeq=r(ge0)
gen geb1_aeq=r(between_ge1)
gen gew1_aeq=r(within_ge1)
gen get1_aeq=r(ge1)
gen p90p50_aeq=r(p90p50)
gen p90p10_aeq=r(p90p10)

replace xb=ln(xb)

summ xb [aw=ww]
gen se_aeq=r(Var)

replace xb=exp(xb)

summ xb [aw=ww]
gen mean_aeq=r(mean)

gen id=1

collapse (mean) ge* se* p90* mean*  id
saveold aej_dcxb_aeq, replace


**---Only countries with data geo-referenced to municipalities

use temp_decompintl, clear

ineqdeco xb [aw=ww] if mun==1, bygroup(ccnum)

gen geb0_meq=r(between_ge0)
gen gew0_meq=r(within_ge0)
gen get0_meq=r(ge0)
gen geb1_meq=r(between_ge1)
gen gew1_meq=r(within_ge1)
gen get1_meq=r(ge1)
gen p90p50_meq=r(p90p50)
gen p90p10_meq=r(p90p10)

replace xb=ln(xb)

summ xb if mun==1 [aw=ww]
gen se_meq=r(Var)

replace xb=exp(xb)

summ xb if mun==1 [aw=ww]
gen mean_meq=r(mean)

gen id=2

collapse (mean) ge* se* p90* mean*  id
saveold aej_dcxb_meq, replace


**--Only countries with data geo-referenced to larger regions

use temp_decompintl, clear

ineqdeco xb [aw=ww] if mun==0, bygroup(ccnum)

gen geb0_req=r(between_ge0)
gen gew0_req=r(within_ge0)
gen get0_req=r(ge0)
gen geb1_req=r(between_ge1)
gen gew1_req=r(within_ge1)
gen get1_req=r(ge1)
gen p90p50_req=r(p90p50)
gen p90p10_req=r(p90p10)

replace xb=ln(xb)

summ xb if mun==0 [aw=ww]
gen se_req=r(Var)

replace xb=exp(xb)

summ xb if mun==0 [aw=ww]
gen mean_req=r(mean)

gen id=3

collapse (mean) ge* se* p90* mean*  id
saveold aej_dcxb_req, replace


*All countries, no U.S. or Canada

use temp_decompintl, clear

ineqdeco xb [aw=ww] if (cntry!="US" & cntry!="CA"), bygroup(ccnum)
gen geb0_aeq_nous=r(between_ge0)
gen gew0_aeq_nous=r(within_ge0)
gen get0_aeq_nous=r(ge0)
gen geb1_aeq_nous=r(between_ge1)
gen gew1_aeq_nous=r(within_ge1)
gen get1_aeq_nous=r(ge1)
gen p90p50_aeq_nous=r(p90p50)
gen p90p10_aeq_nous=r(p90p10)

replace xb=ln(xb)

summ xb if (cntry!="US" & cntry!="CA") [aw=ww]
gen se_aeq_nous=r(Var)

replace xb=exp(xb)

summ xb if (cntry!="US" & cntry!="CA") [aw=ww]
gen mean_aeq_nous=r(mean)

gen id=4

collapse (mean) ge* se* p90* mean*  id
saveold aej_dcxb_aeq_nous, replace


**---Municipality countries; no U.S.

use temp_decompintl, clear

ineqdeco xb [aw=ww] if (mun==1 & cntry!="US"), bygroup(ccnum)

gen geb0_meq_nous=r(between_ge0)
gen gew0_meq_nous=r(within_ge0)
gen get0_meq_nous=r(ge0)
gen geb1_meq_nous=r(between_ge1)
gen gew1_meq_nous=r(within_ge1)
gen get1_meq_nous=r(ge1)
gen p90p50_meq_nous=r(p90p50)
gen p90p10_meq_nous=r(p90p10)

replace xb=ln(xb)

summ xb if (cntry!="US" & mun==1) [aw=ww]
gen se_meq_nous=r(Var)

replace xb=exp(xb)

summ xb if (cntry!="US" & mun==1) [aw=ww]
gen mean_meq_nous=r(mean)

gen id=5

collapse (mean) ge* se* p90* mean*  id
saveold aej_dcxb_meq_nous, replace


**---Merge output together

use aej_dcxb_aeq, clear
append using aej_dcxb_meq
append using aej_dcxb_req
append using aej_dcxb_aeq_nous
append using aej_dcxb_meq_nous
saveold $thedir/aej_dcxbeq, replace



**********************************
**----Actual Population Weights
**********************************


**--Calculate inequality across all countries

use temp_decompint2, clear

ineqdeco xb [aw=ww], bygroup(ccnum)
gen geb0_aact=r(between_ge0)
gen gew0_aact=r(within_ge0)
gen get0_aact=r(ge0)
gen geb1_aact=r(between_ge1)
gen gew1_aact=r(within_ge1)
gen get1_aact=r(ge1)
gen p90p50_aact=r(p90p50)
gen p90p10_aact=r(p90p10)

replace xb=ln(xb)

summ xb [aw=ww]
gen se_aact=r(Var)

replace xb=exp(xb)

summ xb [aw=ww]
gen mean_aact=r(mean)

gen id=1

collapse (mean) ge* se* p90* mean*  id
saveold aej_dcxb_aact, replace


**---Only countries with data geo-referenced to municipalities

use temp_decompint2, clear

ineqdeco xb [aw=ww] if mun==1, bygroup(ccnum)

gen geb0_mact=r(between_ge0)
gen gew0_mact=r(within_ge0)
gen get0_mact=r(ge0)
gen geb1_mact=r(between_ge1)
gen gew1_mact=r(within_ge1)
gen get1_mact=r(ge1)
gen p90p50_mact=r(p90p50)
gen p90p10_mact=r(p90p10)

replace xb=ln(xb)

summ xb if mun==1 [aw=ww]
gen se_mact=r(Var)

replace xb=exp(xb)

summ xb if mun==1 [aw=ww]
gen mean_mact=r(mean)

gen id=2

collapse (mean) ge* se* p90* mean*  id
saveold aej_dcxb_mact, replace


**--Only countries with data geo-referenced to larger regions

use temp_decompint2, clear

ineqdeco xb [aw=ww] if mun==0, bygroup(ccnum)

gen geb0_ract=r(between_ge0)
gen gew0_ract=r(within_ge0)
gen get0_ract=r(ge0)
gen geb1_ract=r(between_ge1)
gen gew1_ract=r(within_ge1)
gen get1_ract=r(ge1)
gen p90p50_ract=r(p90p50)
gen p90p10_ract=r(p90p10)

replace xb=ln(xb)

summ xb if mun==0 [aw=ww]
gen se_ract=r(Var)

replace xb=exp(xb)

summ xb if mun==0 [aw=ww]
gen mean_ract=r(mean)

gen id=3

collapse (mean) ge* se* p90* mean*  id
saveold aej_dcxb_ract, replace


**---Merge output together

use aej_dcxb_aact, clear
mmerge id using aej_dcxb_mact, type(1:1)
mmerge id using aej_dcxb_ract, type(1:1)
drop _merge
saveold $thedir/aej_dcxbact, replace


