*******************************************************************************
*Decompose total income inequality for 18 to 55 year old males into between
*country and within country components
*******************************************************************************

capture log close
clear
set mem 18000000
global thedir = "INSERT DIRECTORY FOR FINAL DATA OUTPUT HERE"
global aejfinalcode = "INSERT DIRECTORY CONTAINING DATA INPUTS HERE"
cd $aejfinalcode
log using aej_dcysmall, replace


/*Data files used as inputs:
			ry`Y'.dta
			Y=BL, BR, CA, CI, CO, EC, ES, GT, HO, MX, PA, PE, PM, US, UY, VE
				 (These are the results of the Mincer decompositions, by country, with the 
				 FIPS country code used in the file naming convention. All are produced 
				 by aej_mincer.do)
Final data files produced (will be inputs into the Matlab file aej_inequality.m)
			aej_dcysmeq (decompositions using equal population weights)
			aej_dcysmact (decompositions using actual population weights)
*/

/* ***---Note: You must download and install the Stata add-on module
	ineqdeco to run this file. Type ssc install ineqdeco from the Stata command
	line or see http://ideas.repec.org/c/boc/bocode/s366002.html
	
	Stephen P. Jenkins, 1999. "INEQDECO: Stata module to calculate inequality indices with 
	decomposition by subgroup,"  Statistical Software Components S366002, Boston College 
	Department of Economics, revised 26 May 2008.
*/

/* ***---Note: This file decomposes income inequality in the Americas into
		inequality across countries and inequality within countries. The output 
		of this file is used as input into the Matlab file inequality.m, which further 
		decomposes total inequality into cross-country, cross-municipality, and 
		within-municipality inequality. 
*/

**************************************
***--Equal Population Weights
**************************************


**--Merge country level files (produced by the file aej_mincer.do)

use ryBL, clear
append using ryBR
append using ryCA
append using ryCI
append using ryCO
append using ryEC
append using ryES
append using ryGT
append using ryHO
append using ryMX
append using ryPA
append using ryPE
append using ryPM
append using ryUS
append using ryUY
append using ryVE

keep admin1 admin2 admin3 cntry yepcip ww xb yres

replace admin2=0 if admin2==.
replace admin3=0 if admin3==.
encode cntry, g(ccnum)
tab ccnum
gen mun=.
replace mun=0 if (admin3==0)
recode mun (.=1)


replace yepcip=exp(yepcip)
replace yres=exp(yres)
replace xb=exp(xb)
gen munic=100000*admin1+admin3
replace munic=10000*admin1+100*admin2 + admin3 if cntry=="PE"
save temp_decompintl, replace


**--Calculate inequality across all countries

ineqdeco yepcip [aw=ww], bygroup(ccnum)
gen geb0_aeq=r(between_ge0)
gen gew0_aeq=r(within_ge0)
gen get0_aeq=r(ge0)
gen geb1_aeq=r(between_ge1)
gen gew1_aeq=r(within_ge1)
gen get1_aeq=r(ge1)
gen p90p50_aeq=r(p90p50)
gen p90p10_aeq=r(p90p10)

replace yepcip=ln(yepcip)

summ yepcip [aw=ww]
gen se_aeq=r(Var)

replace yepcip=exp(yepcip)

summ yepcip [aw=ww]
gen mean_aeq=r(mean)

gen id=1

collapse (mean) ge* se* p90* mean*  id
saveold aej_dcysm_aeq, replace


**---Only countries with data geo-referenced to municipalities

use temp_decompintl, clear

ineqdeco yepcip [aw=ww] if mun==1, bygroup(ccnum)

gen geb0_meq=r(between_ge0)
gen gew0_meq=r(within_ge0)
gen get0_meq=r(ge0)
gen geb1_meq=r(between_ge1)
gen gew1_meq=r(within_ge1)
gen get1_meq=r(ge1)
gen p90p50_meq=r(p90p50)
gen p90p10_meq=r(p90p10)

replace yepcip=ln(yepcip)

summ yepcip if mun==1 [aw=ww]
gen se_meq=r(Var)

replace yepcip=exp(yepcip)

summ yepcip if mun==1 [aw=ww]
gen mean_meq=r(mean)

gen id=2

collapse (mean) ge* se* p90* mean*  id
saveold aej_dcysm_meq, replace


**--Only countries with data geo-referenced to larger regions

use temp_decompintl, clear

ineqdeco yepcip [aw=ww] if mun==0, bygroup(ccnum)

gen geb0_req=r(between_ge0)
gen gew0_req=r(within_ge0)
gen get0_req=r(ge0)
gen geb1_req=r(between_ge1)
gen gew1_req=r(within_ge1)
gen get1_req=r(ge1)
gen p90p50_req=r(p90p50)
gen p90p10_req=r(p90p10)

replace yepcip=ln(yepcip)

summ yepcip if mun==0 [aw=ww]
gen se_req=r(Var)

replace yepcip=exp(yepcip)

summ yepcip if mun==0 [aw=ww]
gen mean_req=r(mean)

gen id=3

collapse (mean) ge* se* p90* mean*  id
saveold aej_dcysm_req, replace


*All countries, no U.S. or Canada

use temp_decompintl, clear

ineqdeco yepcip [aw=ww] if (cntry!="US" & cntry!="CA"), bygroup(ccnum)
gen geb0_aeq_nous=r(between_ge0)
gen gew0_aeq_nous=r(within_ge0)
gen get0_aeq_nous=r(ge0)
gen geb1_aeq_nous=r(between_ge1)
gen gew1_aeq_nous=r(within_ge1)
gen get1_aeq_nous=r(ge1)
gen p90p50_aeq_nous=r(p90p50)
gen p90p10_aeq_nous=r(p90p10)

replace yepcip=ln(yepcip)

summ yepcip if (cntry!="US" & cntry!="CA") [aw=ww]
gen se_aeq_nous=r(Var)

replace yepcip=exp(yepcip)

summ yepcip if (cntry!="US" & cntry!="CA") [aw=ww]
gen mean_aeq_nous=r(mean)

gen id=4

collapse (mean) ge* se* p90* mean*  id
saveold aej_dcysm_aeq_nous, replace


**---Municipality countries; no U.S.

use temp_decompintl, clear

ineqdeco yepcip [aw=ww] if (mun==1 & cntry!="US"), bygroup(ccnum)

gen geb0_meq_nous=r(between_ge0)
gen gew0_meq_nous=r(within_ge0)
gen get0_meq_nous=r(ge0)
gen geb1_meq_nous=r(between_ge1)
gen gew1_meq_nous=r(within_ge1)
gen get1_meq_nous=r(ge1)
gen p90p50_meq_nous=r(p90p50)
gen p90p10_meq_nous=r(p90p10)

replace yepcip=ln(yepcip)

summ yepcip if (cntry!="US" & mun==1) [aw=ww]
gen se_meq_nous=r(Var)

replace yepcip=exp(yepcip)

summ yepcip if (cntry!="US" & mun==1) [aw=ww]
gen mean_meq_nous=r(mean)

gen id=5

collapse (mean) ge* se* p90* mean*  id
saveold aej_dcysm_meq_nous, replace


**---Merge output together

use aej_dcysm_aeq, clear
append using aej_dcysm_meq
append using aej_dcysm_req
append using aej_dcysm_aeq_nous
append using aej_dcysm_meq_nous
saveold $thedir/aej_dcysmeq, replace


**************************************
***--Actual Population Weights
**************************************

**--Merge country level files (produced by the file aej_mincer.do)

use ryBL, clear
append using ryBR
append using ryCA
append using ryCI
append using ryCO
append using ryEC
append using ryES
append using ryGT
append using ryHO
append using ryMX
append using ryPA
append using ryPE
append using ryPM
append using ryUS
append using ryUY
append using ryVE

keep admin1 admin2 admin3 cntry yepcip xb yres pop00
replace admin2=0 if admin2==.
replace admin3=0 if admin3==.

gen obs=1
collapse (sum) obs (mean) pop00, by(cntry admin1 admin2 admin3)
egen double total=sum(pop00)

*create population weights

gen ww=100000*((pop00/obs)/total)
keep ww admin1 admin2 admin3 cntry obs
sum ww
sort admin1 admin2 admin3 cntry
save tempwts_y, replace

use ryBL, clear
append using ryBR
append using ryCA
append using ryCI
append using ryCO
append using ryEC
append using ryES
append using ryGT
append using ryHO
append using ryMX
append using ryPA
append using ryPE
append using ryPM
append using ryUS
append using ryUY
append using ryVE

replace admin2=0 if admin2==.
replace admin3=0 if admin3==.

keep admin1 admin2 admin3 cntry yepcip xb yres
sort admin1 admin2 admin3 cntry
merge admin1 admin2 admin3 cntry using tempwts_y, uniqusing
tab _merge
drop _merge

encode cntry, g(ccnum)

replace yepcip=exp(yepcip)
replace xb=exp(xb)
replace yres=exp(yres)

gen mun=.
replace mun=0 if (admin3==0)
recode mun (.=1)

save temp_decompint2, replace


**--Calculate inequality across all countries

ineqdeco yepcip [aw=ww], bygroup(ccnum)
gen geb0_aact=r(between_ge0)
gen gew0_aact=r(within_ge0)
gen get0_aact=r(ge0)
gen geb1_aact=r(between_ge1)
gen gew1_aact=r(within_ge1)
gen get1_aact=r(ge1)
gen p90p50_aact=r(p90p50)
gen p90p10_aact=r(p90p10)

replace yepcip=ln(yepcip)

summ yepcip [aw=ww]
gen se_aact=r(Var)

replace yepcip=exp(yepcip)

summ yepcip [aw=ww]
gen mean_aact=r(mean)

gen id=1

collapse (mean) ge* se* p90* mean*  id
saveold aej_dcysm_aact, replace


**---Only countries with data geo-referenced to municipalities

use temp_decompint2, clear

ineqdeco yepcip [aw=ww] if mun==1, bygroup(ccnum)

gen geb0_mact=r(between_ge0)
gen gew0_mact=r(within_ge0)
gen get0_mact=r(ge0)
gen geb1_mact=r(between_ge1)
gen gew1_mact=r(within_ge1)
gen get1_mact=r(ge1)
gen p90p50_mact=r(p90p50)
gen p90p10_mact=r(p90p10)

replace yepcip=ln(yepcip)

summ yepcip if mun==1 [aw=ww]
gen se_mact=r(Var)

replace yepcip=exp(yepcip)

summ yepcip if mun==1 [aw=ww]
gen mean_mact=r(mean)

gen id=2

collapse (mean) ge* se* p90* mean*  id
saveold aej_dcysm_mact, replace


**--Only countries with data geo-referenced to larger regions

use temp_decompint2, clear

ineqdeco yepcip [aw=ww] if mun==0, bygroup(ccnum)

gen geb0_ract=r(between_ge0)
gen gew0_ract=r(within_ge0)
gen get0_ract=r(ge0)
gen geb1_ract=r(between_ge1)
gen gew1_ract=r(within_ge1)
gen get1_ract=r(ge1)
gen p90p50_ract=r(p90p50)
gen p90p10_ract=r(p90p10)

replace yepcip=ln(yepcip)

summ yepcip if mun==0 [aw=ww]
gen se_ract=r(Var)

replace yepcip=exp(yepcip)

summ yepcip if mun==0 [aw=ww]
gen mean_ract=r(mean)

gen id=3

collapse (mean) ge* se* p90* mean*  id
saveold aej_dcysm_ract, replace


**---Merge output together

use aej_dcysm_aact, clear
mmerge id using aej_dcysm_mact, type(1:1)
mmerge id using aej_dcysm_ract, type(1:1)
drop _merge
saveold $thedir/aej_dcysmact, replace



