%Decomposes total income inequality (all individuals), total income inequality (males 18-55),
% predicted income inequality (males 18-55), and residual income inequality (males 18-55)
% into across-country, across-municipality, and within-municipality components

%Input files:
%ytotal.txt
%ydecomp.txt

%Output files used in Table 1 (Total income inequality, all individuals):
%yall_actual.tex - All countries, actual population weights
%ymun_actual.tex - Countries with data referenced to municipalities, actual population weights
%yreg_actual.tex - Countries with data referenced to regions, actual population weights
%yall_hyp.tex - All countries, equal population weights
%yallUS_hyp.tex - All countries, equal population weights, no U.S. or Canada
%ymun_hyp.tex - Countries with data referenced to municipalities, equal population weights
%ymunUS_hyp.tex - Countries with data referenced to municipalities, equal population weights, no U.S.
%yreg_hyp.tex - Countries with data referenced to regions, equal population weights

%Output files used in Table 2 (Total, predicted, and residual income inequality,
%males 18-55):
%ysmall1_actual.tex - All countries, actual population weights
%ymun1_actual.tex - Countries with data referenced to municipalities, actual population weights
%yreg1_actual.tex - Countries with data referenced to regions, actual population weights
%ysmal11_hyp.tex - All countries, equal population weights
%ymun1_hyp.tex - Countries with data referenced to municipalities, equal population weights
%ymunnoNA1_hyp.tex - Countries with data referenced to municipalities, equal population weights, no U.S.
%yreg1_hyp.tex - Countries with data referenced to regions, equal population weights
%yallnoNA1_hyp.tex - All countries, equal population weights, no U.S. or Canada




%% Decomposing income inequality (all individuals)



% Load Data

  clear; %clear data
  clc; %clear command window

  % Load in dataset;
  load ytotal.txt;
  
  % variables: id	yj	gb0	gw0	gt0	gb1	gw1	gt1	nj nj_eq

% Total Western Hemisphere inequality for the various measures

% taken from Stata files: aej_dcyact, aej_dcyeq

GE0all_actual	=	0.9024374;

GE1all_actual	=	0.7958267;

GE0mun_actual	=	0.8992221;

GE1mun_actual	=	0.7936462;

GE0reg_actual	=	0.8568581;

GE1reg_actual	=	0.7318034;
		
		
GE0all_hyp	=	0.8777642;

GE1all_hyp	=	0.853636;

GE0mun_hyp	=	0.8946088;

GE1mun_hyp	=	0.9075633;

GE0reg_hyp	=	0.8149747;

GE1reg_hyp	=	0.7540956;

GE0allUS_hyp	=	0.7596779;

GE1allUS_hyp	=	0.7975905;

GE0munUS_hyp	=	0.7287663;

GE1munUS_hyp	=	0.7539477;


%All countries - actual population

disp('All countries; yall Theil - actual population')

id=ytotal(:,1);
yj=ytotal(:,2);
gb0=ytotal(:,3);
gw0=ytotal(:,4);
gt0=ytotal(:,5);
gb1=ytotal(:,6);
gw1=ytotal(:,7);
gt1=ytotal(:,8);
nj=ytotal(:,9);
nj_eq=ytotal(:,10);

njyj=nj.*yj;
ny=sum(njyj);
wt=njyj./ny;
sum(wt);
wc1=wt.*gt1;
wc1=sum(wc1)
bc1 = GE1all_actual-wc1
wm1=wt.*gw1;
wm1=sum(wm1)
bm1=wt.*gb1;
bm1=sum(bm1)

disp('All countries; yall MLD - actual population')

n=sum(nj);
wt=nj./n;
sum(wt);
wc0=wt.*gt0;
wc0=sum(wc0)
bc0= GE0all_actual-wc0
wm0=wt.*gw0;
wm0=sum(wm0)
bm0=wt.*gb0;
bm0=sum(bm0)

yall_actual=[bc0,wc0,bm0,wm0,bc1,wc1,bm1,wm1];
columnLabels = {'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.', 'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.' };
rowLabels = {'All Countries - Actual Pop'};  
matrix2latex(yall_actual, 'yall_actual.tex', 'rowLabels', rowLabels, 'columnLabels', columnLabels, 'alignment', 'c', 'format', '%-6.3f', 'size', 'footnotesize');

%Geo-referenced to municipality - actual population 

disp('Geo-referenced to municipality; yall Theil - actual population ')

id=ytotal(:,1);
yj=ytotal(:,2);
gb0=ytotal(:,3);
gw0=ytotal(:,4);
gt0=ytotal(:,5);
gb1=ytotal(:,6);
gw1=ytotal(:,7);
gt1=ytotal(:,8);
nj=ytotal(:,9);
nj_eq=ytotal(:,10);

yj=yj(id<=11);
gb0=gb0(id<=11);
gw0=gw0(id<=11);
gt0=gt0(id<=11);
gb1=gb1(id<=11);
gw1=gw1(id<=11);
gt1=gt1(id<=11);
nj=nj(id<=11);
nj_eq=nj_eq(id<=11);

njyj=nj.*yj;
ny=sum(njyj);
wt=njyj./ny;
sum(wt);
wc1=wt.*gt1;
wc1=sum(wc1)
bc1=GE1mun_actual-wc1
wm1=wt.*gw1;
wm1=sum(wm1)
bm1=wt.*gb1;
bm1=sum(bm1)

disp('Geo-referenced to municipality; yall MLD - actual population ')

n=sum(nj);
wt=nj./n;
sum(wt);
wc0=wt.*gt0;
wc0=sum(wc0)
bc0=GE0mun_actual-wc0
wm0=wt.*gw0;
wm0=sum(wm0)
bm0=wt.*gb0;
bm0=sum(bm0)

ymun_actual=[bc0,wc0,bm0,wm0,bc1,wc1,bm1,wm1];
columnLabels = {'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.', 'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.' };
rowLabels = {'Ref. to Munic. - Actual Pop'};  
matrix2latex(ymun_actual, 'ymun_actual.tex', 'rowLabels', rowLabels, 'columnLabels', columnLabels, 'alignment', 'c', 'format', '%-6.3f', 'size', 'footnotesize');

%Geo-referenced to region - actual population 

disp('Geo-referenced to region; yall Theil - assume equal population ')


id=ytotal(:,1);
yj=ytotal(:,2);
gb0=ytotal(:,3);
gw0=ytotal(:,4);
gt0=ytotal(:,5);
gb1=ytotal(:,6);
gw1=ytotal(:,7);
gt1=ytotal(:,8);
nj=ytotal(:,9);
nj_eq=ytotal(:,10);

yj=yj(id>11);
gb0=gb0(id>11);
gw0=gw0(id>11);
gt0=gt0(id>11);
gb1=gb1(id>11);
gw1=gw1(id>11);
gt1=gt1(id>11);
nj=nj(id>11);
nj_eq=nj_eq(id>11);

njyj=nj.*yj;
ny=sum(njyj);
wt=njyj./ny;
sum(wt);
wc1=wt.*gt1;
wc1=sum(wc1)
bc1=GE1reg_actual-wc1
wm1=wt.*gw1;
wm1=sum(wm1)
bm1=wt.*gb1;
bm1=sum(bm1)


n=sum(nj);
wt=nj./n;
sum(wt);
wc0=wt.*gt0;
wc0=sum(wc0)
bc0=GE0reg_actual-wc0
wm0=wt.*gw0;
wm0=sum(wm0)
bm0=wt.*gb0;
bm0=sum(bm0)

yreg_actual=[GE0reg_actual,bc0,wc0,bm0,wm0,GE1reg_actual,bc1,wc1,bm1,wm1];
columnLabels = {'total','Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.','total' 'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.' };
rowLabels = {'Ref. to Region. - Actual Pop'};  
matrix2latex(yreg_actual, 'yreg_actual.tex', 'rowLabels', rowLabels, 'columnLabels', columnLabels, 'alignment', 'c', 'format', '%-6.3f', 'size', 'footnotesize');


%All countries - assume equal population

disp('All countries; yall Theil - assume equal population')

id=ytotal(:,1);
yj=ytotal(:,2);
gb0=ytotal(:,3);
gw0=ytotal(:,4);
gt0=ytotal(:,5);
gb1=ytotal(:,6);
gw1=ytotal(:,7);
gt1=ytotal(:,8);
nj=ytotal(:,9);
nj_eq=ytotal(:,10);

njyj=nj_eq.*yj;
ny=sum(njyj);
wt=njyj./ny;
sum(wt);
wc1=wt.*gt1;
wc1=sum(wc1)
bc1 = GE1all_hyp-wc1
wm1=wt.*gw1;
wm1=sum(wm1)
bm1=wt.*gb1;
bm1=sum(bm1)


n=sum(nj_eq);
wt=nj_eq./n;
sum(wt);
wc0=wt.*gt0;
wc0=sum(wc0)
bc0= GE0all_hyp-wc0
wm0=wt.*gw0;
wm0=sum(wm0)
bm0=wt.*gb0;
bm0=sum(bm0)

yall_hyp=[bc0,wc0,bm0,wm0,bc1,wc1,bm1,wm1];
columnLabels = {'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.', 'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.' };
rowLabels = {'All Countries - Equal Pop'};  
matrix2latex(yall_hyp, 'yall_hyp.tex', 'rowLabels', rowLabels, 'columnLabels', columnLabels, 'alignment', 'c', 'format', '%-6.3f', 'size', 'footnotesize');

% Whole sample - no U.S. or Canada

yj=yj(id~=10 & id~=12);
gb0=gb0(id~=10 & id~=12);
gw0=gw0(id~=10 & id~=12);
gt0=gt0(id~=10 & id~=12);
gb1=gb1(id~=10 & id~=12);
gw1=gw1(id~=10 & id~=12);
gt1=gt1(id~=10 & id~=12);
nj=nj(id~=10 & id~=12);
nj_eq=nj_eq(id~=10 & id~=12);

njyj=nj_eq.*yj;
ny=sum(njyj);
wt=njyj./ny;
sum(wt);
wc1=wt.*gt1;
wc1=sum(wc1)
bc1 = GE1allUS_hyp-wc1
wm1=wt.*gw1;
wm1=sum(wm1)
bm1=wt.*gb1;
bm1=sum(bm1)


n=sum(nj_eq);
wt=nj_eq./n;
sum(wt);
wc0=wt.*gt0;
wc0=sum(wc0)
bc0= GE0allUS_hyp-wc0
wm0=wt.*gw0;
wm0=sum(wm0)
bm0=wt.*gb0;
bm0=sum(bm0)

yallUS_hyp=[bc0,wc0,bm0,wm0,bc1,wc1,bm1,wm1];
columnLabels = {'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.', 'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.' };
rowLabels = {'All Countries - Equal Pop'};  
matrix2latex(yallUS_hyp, 'yallUS_hyp.tex', 'rowLabels', rowLabels, 'columnLabels', columnLabels, 'alignment', 'c', 'format', '%-6.3f', 'size', 'footnotesize');


%Geo-referenced to municipality - assume equal population 

disp('Geo-referenced to municipality; yall Theil - assume equal population ')

id=ytotal(:,1);
yj=ytotal(:,2);
gb0=ytotal(:,3);
gw0=ytotal(:,4);
gt0=ytotal(:,5);
gb1=ytotal(:,6);
gw1=ytotal(:,7);
gt1=ytotal(:,8);
nj=ytotal(:,9);
nj_eq=ytotal(:,10);

yj=yj(id<=11);
gb0=gb0(id<=11);
gw0=gw0(id<=11);
gt0=gt0(id<=11);
gb1=gb1(id<=11);
gw1=gw1(id<=11);
gt1=gt1(id<=11);
nj=nj(id<=11);
nj_eq=nj_eq(id<=11);

njyj=nj_eq.*yj;
ny=sum(njyj);
wt=njyj./ny;
sum(wt);
wc1=wt.*gt1;
wc1=sum(wc1)
bc1=GE1mun_hyp-wc1
wm1=wt.*gw1;
wm1=sum(wm1)
bm1=wt.*gb1;
bm1=sum(bm1)


n=sum(nj_eq);
wt=nj_eq./n;
sum(wt);;
wc0=wt.*gt0;
wc0=sum(wc0)
bc0=GE0mun_hyp-wc0
wm0=wt.*gw0;
wm0=sum(wm0)
bm0=wt.*gb0;
bm0=sum(bm0)

ymun_hyp=[bc0,wc0,bm0,wm0,bc1,wc1,bm1,wm1];
columnLabels = {'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.', 'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.' };
rowLabels = {'Ref. to Munic. - Equal Pop'};  
matrix2latex(ymun_hyp, 'ymun_hyp.tex', 'rowLabels', rowLabels, 'columnLabels', columnLabels, 'alignment', 'c', 'format', '%-6.3f', 'size', 'footnotesize');

% Whole sample - no U.S. or Canada


id=ytotal(:,1);
yj=ytotal(:,2);
gb0=ytotal(:,3);
gw0=ytotal(:,4);
gt0=ytotal(:,5);
gb1=ytotal(:,6);
gw1=ytotal(:,7);
gt1=ytotal(:,8);
nj=ytotal(:,9);
nj_eq=ytotal(:,10);


yj=yj(id~=10 & id<=11);
gb0=gb0(id~=10 & id<=11);
gw0=gw0(id~=10 & id<=11);
gt0=gt0(id~=10 & id<=11);
gb1=gb1(id~=10 & id<=11);
gw1=gw1(id~=10 & id<=11);
gt1=gt1(id~=10 & id<=11);
nj=nj(id~=10 & id<=11);
nj_eq=nj_eq(id~=10 & id<=11);

njyj=nj_eq.*yj;
ny=sum(njyj);
wt=njyj./ny;
sum(wt);
wc1=wt.*gt1;
wc1=sum(wc1)
bc1=GE1munUS_hyp-wc1
wm1=wt.*gw1;
wm1=sum(wm1)
bm1=wt.*gb1;
bm1=sum(bm1)


n=sum(nj_eq);
wt=nj_eq./n;
sum(wt);;
wc0=wt.*gt0;
wc0=sum(wc0)
bc0=GE0munUS_hyp-wc0
wm0=wt.*gw0;
wm0=sum(wm0)
bm0=wt.*gb0;
bm0=sum(bm0)

ymunUS_hyp=[bc0,wc0,bm0,wm0,bc1,wc1,bm1,wm1];
columnLabels = {'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.', 'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.' };
rowLabels = {'Ref. to Munic. - Equal Pop'};  
matrix2latex(ymunUS_hyp, 'ymunUS_hyp.tex', 'rowLabels', rowLabels, 'columnLabels', columnLabels, 'alignment', 'c', 'format', '%-6.3f', 'size', 'footnotesize');


%Geo-referenced to region - assume equal population 

disp('Geo-referenced to region; yall Theil - assume equal population ')


id=ytotal(:,1);
yj=ytotal(:,2);
gb0=ytotal(:,3);
gw0=ytotal(:,4);
gt0=ytotal(:,5);
gb1=ytotal(:,6);
gw1=ytotal(:,7);
gt1=ytotal(:,8);
nj=ytotal(:,9);
nj_eq=ytotal(:,10);

yj=yj(id>11);
gb0=gb0(id>11);
gw0=gw0(id>11);
gt0=gt0(id>11);
gb1=gb1(id>11);
gw1=gw1(id>11);
gt1=gt1(id>11);
nj=nj(id>11);
nj_eq=nj_eq(id>11);

njyj=nj_eq.*yj;
ny=sum(njyj);
wt=njyj./ny;
sum(wt);
wc1=wt.*gt1;
wc1=sum(wc1)
bc1=GE1reg_hyp-wc1
wm1=wt.*gw1;
wm1=sum(wm1)
bm1=wt.*gb1;
bm1=sum(bm1)


n=sum(nj_eq);
wt=nj_eq./n;
sum(wt);
wc0=wt.*gt0;
wc0=sum(wc0)
bc0=GE0reg_hyp-wc0
wm0=wt.*gw0;
wm0=sum(wm0)
bm0=wt.*gb0;
bm0=sum(bm0)

yreg_hyp=[bc0,wc0,bm0,wm0,bc1,wc1,bm1,wm1];
columnLabels = {'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.', 'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.' };
rowLabels = {'Ref. to Region. - Equal Pop'};  
matrix2latex(yreg_hyp, 'yreg_hyp.tex', 'rowLabels', rowLabels, 'columnLabels', columnLabels, 'alignment', 'c', 'format', '%-6.3f', 'size', 'footnotesize');

%% Decomposing income inequality (males 18-55)

  clear; %clear data
  clc; %clear command window

  % Load in dataset;
  load ydecomp.txt;
  
  % variables: 1. id	2. yj	3. gt0_y_y	4. gb0_y_y	5. gw0_y_y	6. gt0_y_xb	7. gb0_y_xb	8. gw0_y_xb	9. gt0_y_res	
% 10. gb0_y_res	11. gw0_y_res	12. gt1_y_y	13. gb1_y_y	14. gw1_y_y	15. gt1_y_xb	16. gb1_y_xb	17. gw1_y_xb	
 % 18. gt1_y_res	19. gb1_y_res	20. gw1_y_res	22. nj	22. nj_pwt	23. nj_eq


% Total Western Hemisphere inequality for the various measures

% taken from stata files: aej_dcysmact, aej_dcysmeq, aej_dcxbact, aej_dcxbeq, aej_dcyresact, aej_dcyreseq

GE0all_actual	=	0.8622102;

GE1all_actual	=	0.7626573;

GE0mun_actual	=	0.858129;

GE1mun_actual	=	0.7556207;

GE0reg_actual	=	0.8185507;

GE1reg_actual	=	0.7390298;

GE0all_hyp	=	0.8376828;

GE1all_hyp	=	0.8590935;

GE0mun_hyp	=	0.845648;

GE1mun_hyp	=	0.8790738;

GE0reg_hyp	=	0.781787;

GE1reg_hyp	=	0.7953909;

GE0allUS_hyp	=	0.6971815;

GE1allUS_hyp	=	0.8049166;

GE0munUS_hyp	=	0.6690443;

GE1munUS_hyp	=	0.7128606;
   
GE0allxb_actual	=	0.3492206;

GE1allxb_actual	=	0.306045;

GE0munxb_actual	=	0.3631653;

GE1munxb_actual	=	0.3156309;

GE0regxb_actual	=	0.2562602;

GE1regxb_actual	=	0.231033;

GE0allxb_hyp	=	0.3226783;

GE1allxb_hyp	=	0.3243193;

GE0munxb_hyp	=	0.3194867;

GE1munxb_hyp	=	0.3481177;

GE0regxb_hyp	=	0.2358194;

GE1regxb_hyp	=	0.2216214;

GE0allUSxb_hyp	=	0.2567465;

GE1allUSxb_hyp	=	0.2742759;

GE0munUSxb_hyp	=	0.219626;

GE1munUSxb_hyp	=	0.2415653;
    
GE0allres_actual	=	0.419799;

GE1allres_actual	=	0.4685634;

GE0munres_actual	=	0.410317;

GE1munres_actual	=	0.4612431;

GE0regres_actual	=	0.4340876;

GE1regres_actual	=	0.477136;
	 	
GE0allres_hyp	=	0.4785721;

GE1allres_hyp	=	0.5206246;

GE0munres_hyp	=	0.4858744;

GE1munres_hyp	=	0.4981869;

GE0regres_hyp	=	0.4427693;

GE1regres_hyp	=	0.5609161;

GE0allUSres_hyp	=	0.4895408;

GE1allUSres_hyp	=	0.5589276;

GE0munUSres_hyp	=	0.4955643;

GE1munUSres_hyp	=	0.5177104;


%% All countries - actual population

disp('All countries; ysall Theil - actual population')

% variables: 1. id	2. yj	3. gt0_y	4. gb0_y	5. gw0_y	6. gt0_xb	7. gb0_xb	8. gw0_xb	9. gt0_res	
% 10. gb0_res	11. gw0_res	12. gt1_y	13. gb1_y	14. gw1_y	15. gt1_xb	16. gb1_xb	17. gw1_xb	
 % 18. gt1_res	19. gb1_res	20. gw1_res	22. nj	22. nj_pwt	23. nj_eq

id=ydecomp(:,1);
yj=ydecomp(:,2);
gt0_y=ydecomp(:,3);
gb0_y=ydecomp(:,4);
gw0_y=ydecomp(:,5);
gt0_xb=ydecomp(:,6);
gb0_xb=ydecomp(:,7);
gw0_xb=ydecomp(:,8);
gt0_res=ydecomp(:,9);
gb0_res=ydecomp(:,10);
gw0_res=ydecomp(:,11);
gt1_y=ydecomp(:,12);
gb1_y=ydecomp(:,13);
gw1_y=ydecomp(:,14);
gt1_xb=ydecomp(:,15);
gb1_xb=ydecomp(:,16);
gw1_xb=ydecomp(:,17);
gt1_res=ydecomp(:,18);
gb1_res=ydecomp(:,19);
gw1_res=ydecomp(:,20);
nj=ydecomp(:,21);
nj_eq=ydecomp(:,22);
yresj=ydecomp(:,23);
xbj=ydecomp(:,24);


njyj=nj.*yj;
ny=sum(njyj);
wt=njyj./ny;
sum(wt);
wc1_y=wt.*gt1_y;
wc1_y=sum(wc1_y)
bc1 = GE1all_actual-wc1_y
wm1_y=wt.*gw1_y;
wm1_y=sum(wm1_y)
bm1_y=wt.*gb1_y;
bm1_y=sum(bm1_y)

disp('All countries; ysall MLD - actual population')

n=sum(nj);
wt=nj./n;
sum(wt);
wc0_y=wt.*gt0_y;
wc0_y=sum(wc0_y)
bc0_y= GE0all_actual-wc0_y
wm0_y_y=wt.*gw0_y;
wm0_y_y=sum(wm0_y_y)
bm0_y=wt.*gb0_y;
bm0_y=sum(bm0_y)

disp('All countries; xball Theil - actual population')

njyj=nj.*xbj;
ny=sum(njyj);
wt=njyj./ny;
sum(wt);
wc1_xb=wt.*gt1_xb;
wc1_xb=sum(wc1_xb)
bc1_xb = GE1allxb_actual-wc1_xb
wm1_xb=wt.*gw1_xb;
wm1_xb=sum(wm1_xb)
bm1_xb=wt.*gb1_xb;
bm1_xb=sum(bm1_xb)

disp('All countries; xball MLD - actual population')

n=sum(nj);
wt=nj./n;
sum(wt);
wc0_xb=wt.*gt0_xb;
wc0_xb=sum(wc0_xb)
bc0_xb= GE0allxb_actual-wc0_xb
wm0_xb=wt.*gw0_xb;
wm0_xb=sum(wm0_xb)
bm0_xb=wt.*gb0_xb;
bm0_xb=sum(bm0_xb)

disp('All countries; yresall Theil - actual population')

njyj=nj.*yresj;
ny=sum(njyj);
wt=njyj./ny;
sum(wt);
wc1_res=wt.*gt1_res;
wc1_res=sum(wc1_res)
bc1_res = GE1allres_actual-wc1_res
wm1_res=wt.*gw1_res;
wm1_res=sum(wm1_res)
bm1_res=wt.*gb1_res;
bm1_res=sum(bm1_res)

disp('All countries; yresall MLD - actual population')

n=sum(nj);
wt=nj./n;
sum(wt);
wc0_res=wt.*gt0_res;
wc0_res=sum(wc0_res)
bc0_res= GE0allres_actual-wc0_res
wm0_res=wt.*gw0_res;
wm0_res=sum(wm0_res)
bm0_res=wt.*gb0_res;
bm0_res=sum(bm0_res)

ysmall0_actual=[bc0_y,wc0_y,bm0_y,wm0_y_y,bc0_xb,wc0_xb,bm0_xb,wm0_xb,bc0_res,wc0_res,bm0_res,wm0_res];
columnLabels = {'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.', 'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.','Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.' };
rowLabels = {'All Countries - Actual Pop'};  
matrix2latex(ysmall0_actual, 'ysmall0_actual.tex', 'rowLabels', rowLabels, 'columnLabels', columnLabels, 'alignment', 'c', 'format', '%-6.3f', 'size', 'footnotesize');

ysmall1_actual=[bc1,wc1_y,bm1_y,wm1_y,bc1_xb,wc1_xb,bm1_xb,wm1_xb,bc1_res,wc1_res,bm1_res,wm1_res];
columnLabels = {'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.', 'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.','Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.' };
rowLabels = {'All Countries - Actual Pop'};  
matrix2latex(ysmall1_actual, 'ysmall1_actual.tex', 'rowLabels', rowLabels, 'columnLabels', columnLabels, 'alignment', 'c', 'format', '%-6.3f', 'size', 'footnotesize');


%% Geo-referenced to municipality - actual population 

disp('Geo-referenced to municipality; ysall Theil - actual population ')


yj=yj(id<=11);
gt0_y=gt0_y(id<=11);
gb0_y=gb0_y(id<=11);
gw0_y=gw0_y(id<=11);
gt0_xb=gt0_xb(id<=11);
gb0_xb=gb0_xb(id<=11);
gw0_xb=gw0_xb(id<=11);
gt0_res=gt0_res(id<=11);
gb0_res=gb0_res(id<=11);
gw0_res=gw0_res(id<=11);
gt1_y=gt1_y(id<=11);
gb1_y=gb1_y(id<=11);
gw1_y=gw1_y(id<=11);
gt1_xb=gt1_xb(id<=11);
gb1_xb=gb1_xb(id<=11);
gw1_xb=gw1_xb(id<=11);
gt1_res=gt1_res(id<=11);
gb1_res=gb1_res(id<=11);
gw1_res=gw1_res(id<=11);
nj=nj(id<=11);
nj_eq=nj_eq(id<=11);
yresj=yresj(id<=11);
xbj=xbj(id<=11);


njyj=nj.*yj;
ny=sum(njyj);
wt=njyj./ny;
sum(wt);
wc1_y=wt.*gt1_y;
wc1_y=sum(wc1_y)
bc1=GE1mun_actual-wc1_y
wm1_y=wt.*gw1_y;
wm1_y=sum(wm1_y)
bm1_y=wt.*gb1_y;
bm1_y=sum(bm1_y)

disp('Geo-referenced to municipality; ysall MLD - actual population ')

n=sum(nj);
wt=nj./n;
sum(wt);
wc0_y=wt.*gt0_y;
wc0_y=sum(wc0_y)
bc0_y=GE0mun_actual-wc0_y
wm0_y_y=wt.*gw0_y;
wm0_y_y=sum(wm0_y_y)
bm0_y=wt.*gb0_y;
bm0_y=sum(bm0_y)

disp('Geo-referenced to municipality; xball Theil - actual population ')

njyj=nj.*xbj;
ny=sum(njyj);
wt=njyj./ny;
sum(wt);
wc1_xb=wt.*gt1_xb;
wc1_xb=sum(wc1_xb)
bc1_xb=GE1munxb_actual-wc1_xb
wm1_xb=wt.*gw1_xb;
wm1_xb=sum(wm1_xb)
bm1_xb=wt.*gb1_xb;
bm1_xb=sum(bm1_xb)

disp('Geo-referenced to municipality; xball MLD - actual population ')

n=sum(nj);
wt=nj./n;
sum(wt);
wc0_xb=wt.*gt0_xb;
wc0_xb=sum(wc0_xb)
bc0_xb=GE0munxb_actual-wc0_xb
wm0_xb=wt.*gw0_xb;
wm0_xb=sum(wm0_xb)
bm0_xb=wt.*gb0_xb;
bm0_xb=sum(bm0_xb)

disp('Geo-referenced to municipality; yresall Theil - actual population ')

njyj=nj.*yresj;
ny=sum(njyj);
wt=njyj./ny;
sum(wt);
wc1_res=wt.*gt1_res;
wc1_res=sum(wc1_res)
bc1_res=GE1munres_actual-wc1_res
wm1_res=wt.*gw1_res;
wm1_res=sum(wm1_res)
bm1_res=wt.*gb1_res;
bm1_res=sum(bm1_res)

disp('Geo-referenced to municipality; yresall MLD - actual population ')

n=sum(nj);
wt=nj./n;
sum(wt);
wc0_res=wt.*gt0_res;
wc0_res=sum(wc0_res)
bc0_res=GE0munres_actual-wc0_res
wm0_res=wt.*gw0_res;
wm0_res=sum(wm0_res)
bm0_res=wt.*gb0_res;
bm0_res=sum(bm0_res)

ymun0_actual=[bc0_y,wc0_y,bm0_y,wm0_y_y,bc0_xb,wc0_xb,bm0_xb,wm0_xb,bc0_res,wc0_res,bm0_res,wm0_res];
columnLabels = {'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.', 'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.','Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.' };
rowLabels = {'All Countries - Actual Pop'};  
matrix2latex(ymun0_actual, 'ymun0_actual.tex', 'rowLabels', rowLabels, 'columnLabels', columnLabels, 'alignment', 'c', 'format', '%-6.3f', 'size', 'footnotesize');

ymun1_actual=[bc1,wc1_y,bm1_y,wm1_y,bc1_xb,wc1_xb,bm1_xb,wm1_xb,bc1_res,wc1_res,bm1_res,wm1_res];
columnLabels = {'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.', 'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.','Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.' };
rowLabels = {'All Countries - Actual Pop'};  
matrix2latex(ymun1_actual, 'ymun1_actual.tex', 'rowLabels', rowLabels, 'columnLabels', columnLabels, 'alignment', 'c', 'format', '%-6.3f', 'size', 'footnotesize');


%% Geo-referenced to region - actual population 

disp('Geo-referenced to region; ysall Theil - actual population ')

id=ydecomp(:,1);
yj=ydecomp(:,2);
gt0_y=ydecomp(:,3);
gb0_y=ydecomp(:,4);
gw0_y=ydecomp(:,5);
gt0_xb=ydecomp(:,6);
gb0_xb=ydecomp(:,7);
gw0_xb=ydecomp(:,8);
gt0_res=ydecomp(:,9);
gb0_res=ydecomp(:,10);
gw0_res=ydecomp(:,11);
gt1_y=ydecomp(:,12);
gb1_y=ydecomp(:,13);
gw1_y=ydecomp(:,14);
gt1_xb=ydecomp(:,15);
gb1_xb=ydecomp(:,16);
gw1_xb=ydecomp(:,17);
gt1_res=ydecomp(:,18);
gb1_res=ydecomp(:,19);
gw1_res=ydecomp(:,20);
nj=ydecomp(:,21);
nj_eq=ydecomp(:,22);
yresj=ydecomp(:,23);
xbj=ydecomp(:,24);




yj=yj(id>11);
gt0_y=gt0_y(id>11);
gb0_y=gb0_y(id>11);
gw0_y=gw0_y(id>11);
gt0_xb=gt0_xb(id>11);
gb0_xb=gb0_xb(id>11);
gw0_xb=gw0_xb(id>11);
gt0_res=gt0_res(id>11);
gb0_res=gb0_res(id>11);
gw0_res=gw0_res(id>11);
gt1_y=gt1_y(id>11);
gb1_y=gb1_y(id>11);
gw1_y=gw1_y(id>11);
gt1_xb=gt1_xb(id>11);
gb1_xb=gb1_xb(id>11);
gw1_xb=gw1_xb(id>11);
gt1_res=gt1_res(id>11);
gb1_res=gb1_res(id>11);
gw1_res=gw1_res(id>11);
nj=nj(id>11);
nj_eq=nj_eq(id>11);
yresj=yresj(id>11);
xbj=xbj(id>11);


njyj=nj.*yj;
ny=sum(njyj);
wt=njyj./ny;
sum(wt);
wc1_y=wt.*gt1_y;
wc1_y=sum(wc1_y)
bc1=GE1reg_actual-wc1_y
wm1_y=wt.*gw1_y;
wm1_y=sum(wm1_y)
bm1_y=wt.*gb1_y;
bm1_y=sum(bm1_y)

disp('Geo-referenced to region; ysall MLD - actual population ')

n=sum(nj);
wt=nj./n;
sum(wt);
wc0_y=wt.*gt0_y;
wc0_y=sum(wc0_y)
bc0_y=GE0reg_actual-wc0_y
wm0_y_y=wt.*gw0_y;
wm0_y_y=sum(wm0_y_y)
bm0_y=wt.*gb0_y;
bm0_y=sum(bm0_y)

%Geo-referenced to region - actual population 

disp('Geo-referenced to region; xball Theil - actual pop. ')

njyj=nj.*xbj;
ny=sum(njyj);
wt=njyj./ny;
sum(wt);
wc1_xb=wt.*gt1_xb;
wc1_xb=sum(wc1_xb)
bc1_xb=GE1regxb_actual-wc1_xb
wm1_xb=wt.*gw1_xb;
wm1_xb=sum(wm1_xb)
bm1_xb=wt.*gb1_xb;
bm1_xb=sum(bm1_xb)

disp('Geo-referenced to region; xball MLD - actual pop ')

n=sum(nj);
wt=nj./n;
sum(wt);
wc0_xb=wt.*gt0_xb;
wc0_xb=sum(wc0_xb)
bc0_xb=GE0regxb_actual-wc0_xb
wm0_xb=wt.*gw0_xb;
wm0_xb=sum(wm0_xb)
bm0_xb=wt.*gb0_xb;
bm0_xb=sum(bm0_xb)


%Geo-referenced to region - actual population 

disp('Geo-referenced to region; yresall Theil - actual population ')

njyj=nj.*yresj;
ny=sum(njyj);
wt=njyj./ny;
sum(wt);
wc1_res=wt.*gt1_res;
wc1_res=sum(wc1_res)
bc1_res=GE1regres_actual-wc1_res
wm1_res=wt.*gw1_res;
wm1_res=sum(wm1_res)
bm1_res=wt.*gb1_res;
bm1_res=sum(bm1_res)

disp('Geo-referenced to region; yresall MLD - actual population ')

n=sum(nj);
wt=nj./n;
sum(wt);
wc0_res=wt.*gt0_res;
wc0_res=sum(wc0_res)
bc0_res=GE0regres_actual-wc0_res
wm0_res=wt.*gw0_res;
wm0_res=sum(wm0_res)
bm0_res=wt.*gb0_res;
bm0_res=sum(bm0_res)


yreg0_actual=[bc0_y,wc0_y,bm0_y,wm0_y_y,bc0_xb,wc0_xb,bm0_xb,wm0_xb,bc0_res,wc0_res,bm0_res,wm0_res];
columnLabels = {'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.', 'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.','Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.' };
rowLabels = {'All Countries - Actual Pop'};  
matrix2latex(yreg0_actual, 'yreg0_actual.tex', 'rowLabels', rowLabels, 'columnLabels', columnLabels, 'alignment', 'c', 'format', '%-6.3f', 'size', 'footnotesize');

yreg1_actual=[bc1,wc1_y,bm1_y,wm1_y,bc1_xb,wc1_xb,bm1_xb,wm1_xb,bc1_res,wc1_res,bm1_res,wm1_res];
columnLabels = {'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.', 'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.','Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.' };
rowLabels = {'All Countries - Actual Pop'};  
matrix2latex(yreg1_actual, 'yreg1_actual.tex', 'rowLabels', rowLabels, 'columnLabels', columnLabels, 'alignment', 'c', 'format', '%-6.3f', 'size', 'footnotesize');

%% All countries - assume equal population

disp('All countries; ysall Theil - assume equal population')

id=ydecomp(:,1);
yj=ydecomp(:,2);
gt0_y=ydecomp(:,3);
gb0_y=ydecomp(:,4);
gw0_y=ydecomp(:,5);
gt0_xb=ydecomp(:,6);
gb0_xb=ydecomp(:,7);
gw0_xb=ydecomp(:,8);
gt0_res=ydecomp(:,9);
gb0_res=ydecomp(:,10);
gw0_res=ydecomp(:,11);
gt1_y=ydecomp(:,12);
gb1_y=ydecomp(:,13);
gw1_y=ydecomp(:,14);
gt1_xb=ydecomp(:,15);
gb1_xb=ydecomp(:,16);
gw1_xb=ydecomp(:,17);
gt1_res=ydecomp(:,18);
gb1_res=ydecomp(:,19);
gw1_res=ydecomp(:,20);
nj=ydecomp(:,21);
nj_eq=ydecomp(:,22);
yresj=ydecomp(:,23);
xbj=ydecomp(:,24);




njyj=nj_eq.*yj;
ny=sum(njyj);
wt=njyj./ny;
sum(wt);
wc1_y=wt.*gt1_y;
wc1_y=sum(wc1_y)
bc1 = GE1all_hyp-wc1_y
wm1_y=wt.*gw1_y;
wm1_y=sum(wm1_y)
bm1_y=wt.*gb1_y;
bm1_y=sum(bm1_y)

disp('All countries; ysall MLD - assume equal population')

n=sum(nj_eq);
wt=nj_eq./n;
sum(wt);
wc0_y=wt.*gt0_y;
wc0_y=sum(wc0_y)
bc0_y= GE0all_hyp-wc0_y
wm0_y_y=wt.*gw0_y;
wm0_y_y=sum(wm0_y_y)
bm0_y=wt.*gb0_y;
bm0_y=sum(bm0_y)

disp('All countries; xball Theil - assume equal population')

njyj=nj_eq.*xbj;
ny=sum(njyj);
wt=njyj./ny;
sum(wt);
wc1_xb=wt.*gt1_xb;
wc1_xb=sum(wc1_xb)
bc1_xb = GE1allxb_hyp-wc1_xb
wm1_xb=wt.*gw1_xb;
wm1_xb=sum(wm1_xb)
bm1_xb=wt.*gb1_xb;
bm1_xb=sum(bm1_xb)

disp('All countries; xball MLD - assume equal population')

n=sum(nj_eq);
wt=nj_eq./n;
sum(wt);
wc0_xb=wt.*gt0_xb;
wc0_xb=sum(wc0_xb)
bc0_xb= GE0allxb_hyp-wc0_xb
wm0_xb=wt.*gw0_xb;
wm0_xb=sum(wm0_xb)
bm0_xb=wt.*gb0_xb;
bm0_xb=sum(bm0_xb)

%All countries - assume equal population

disp('All countries; yresall Theil - assume equal population')

njyj=nj_eq.*yresj;
ny=sum(njyj);
wt=njyj./ny;
sum(wt);
wc1_res=wt.*gt1_res;
wc1_res=sum(wc1_res)
bc1_res = GE1allres_hyp-wc1_res
wm1_res=wt.*gw1_res;
wm1_res=sum(wm1_res)
bm1_res=wt.*gb1_res;
bm1_res=sum(bm1_res)

disp('All countries; yresall MLD - assume equal population')

n=sum(nj_eq);
wt=nj_eq./n;
sum(wt);
wc0_res=wt.*gt0_res;
wc0_res=sum(wc0_res)
bc0_res= GE0allres_hyp-wc0_res
wm0_res=wt.*gw0_res;
wm0_res=sum(wm0_res)
bm0_res=wt.*gb0_res;
bm0_res=sum(bm0_res)

ysmall0_hyp=[bc0_y,wc0_y,bm0_y,wm0_y_y,bc0_xb,wc0_xb,bm0_xb,wm0_xb,bc0_res,wc0_res,bm0_res,wm0_res];
columnLabels = {'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.', 'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.','Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.' };
rowLabels = {'All Countries - Actual Pop'};  
matrix2latex(ysmall0_hyp, 'ysmall0_hyp.tex', 'rowLabels', rowLabels, 'columnLabels', columnLabels, 'alignment', 'c', 'format', '%-6.3f', 'size', 'footnotesize');

ysmal11_hyp=[bc1,wc1_y,bm1_y,wm1_y,bc1_xb,wc1_xb,bm1_xb,wm1_xb,bc1_res,wc1_res,bm1_res,wm1_res];
columnLabels = {'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.', 'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.','Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.' };
rowLabels = {'All Countries - Actual Pop'};  
matrix2latex(ysmal11_hyp, 'ysmal11_hyp.tex', 'rowLabels', rowLabels, 'columnLabels', columnLabels, 'alignment', 'c', 'format', '%-6.3f', 'size', 'footnotesize');

%% Geo-referenced to municipality - assume equal population 

disp('Geo-referenced to municipality; ysall Theil - assume equal population ')

yj=yj(id<=11);
gt0_y=gt0_y(id<=11);
gb0_y=gb0_y(id<=11);
gw0_y=gw0_y(id<=11);
gt0_xb=gt0_xb(id<=11);
gb0_xb=gb0_xb(id<=11);
gw0_xb=gw0_xb(id<=11);
gt0_res=gt0_res(id<=11);
gb0_res=gb0_res(id<=11);
gw0_res=gw0_res(id<=11);
gt1_y=gt1_y(id<=11);
gb1_y=gb1_y(id<=11);
gw1_y=gw1_y(id<=11);
gt1_xb=gt1_xb(id<=11);
gb1_xb=gb1_xb(id<=11);
gw1_xb=gw1_xb(id<=11);
gt1_res=gt1_res(id<=11);
gb1_res=gb1_res(id<=11);
gw1_res=gw1_res(id<=11);
nj=nj(id<=11);
nj_eq=nj_eq(id<=11);
yresj=yresj(id<=11);
xbj=xbj(id<=11);


njyj=nj_eq.*yj;
ny=sum(njyj);
wt=njyj./ny;
sum(wt);
wc1_y=wt.*gt1_y;
wc1_y=sum(wc1_y)
bc1=GE1mun_hyp-wc1_y
wm1_y=wt.*gw1_y;
wm1_y=sum(wm1_y)
bm1_y=wt.*gb1_y;
bm1_y=sum(bm1_y)

disp('Geo-referenced to municipality; ysall MLD - assume equal population ')

n=sum(nj_eq);
wt=nj_eq./n;
sum(wt);;
wc0_y=wt.*gt0_y;
wc0_y=sum(wc0_y)
bc0_y=GE0mun_hyp-wc0_y
wm0_y_y=wt.*gw0_y;
wm0_y_y=sum(wm0_y_y)
bm0_y=wt.*gb0_y;
bm0_y=sum(bm0_y)

%Geo-referenced to municipality - assume equal population 

disp('Geo-referenced to municipality; xball Theil - assume equal population ')

njyj=nj_eq.*xbj;
ny=sum(njyj);
wt=njyj./ny;
sum(wt);
wc1_xb=wt.*gt1_xb;
wc1_xb=sum(wc1_xb)
bc1_xb=GE1munxb_hyp-wc1_xb
wm1_xb=wt.*gw1_xb;
wm1_xb=sum(wm1_xb)
bm1_xb=wt.*gb1_xb;
bm1_xb=sum(bm1_xb)

disp('Geo-referenced to municipality; xball MLD - assume equal population ')

n=sum(nj_eq);
wt=nj_eq./n;
sum(wt);;
wc0_xb=wt.*gt0_xb;
wc0_xb=sum(wc0_xb)
bc0_xb=GE0munxb_hyp-wc0_xb
wm0_xb=wt.*gw0_xb;
wm0_xb=sum(wm0_xb)
bm0_xb=wt.*gb0_xb;
bm0_xb=sum(bm0_xb)

disp('Geo-referenced to municipality; yresall Theil - assume equal population ')

njyj=nj_eq.*yresj;
ny=sum(njyj);
wt=njyj./ny;
sum(wt);
wc1_res=wt.*gt1_res;
wc1_res=sum(wc1_res)
bc1_res=GE1munres_hyp-wc1_res
wm1_res=wt.*gw1_res;
wm1_res=sum(wm1_res)
bm1_res=wt.*gb1_res;
bm1_res=sum(bm1_res)

disp('Geo-referenced to municipality; yresall MLD - assume equal population ')

n=sum(nj_eq);
wt=nj_eq./n;
sum(wt);;
wc0_res=wt.*gt0_res;
wc0_res=sum(wc0_res)
bc0_res=GE0munres_hyp-wc0_res
wm0_res=wt.*gw0_res;
wm0_res=sum(wm0_res)
bm0_res=wt.*gb0_res;
bm0_res=sum(bm0_res)

ymun0_hyp=[bc0_y,wc0_y,bm0_y,wm0_y_y,bc0_xb,wc0_xb,bm0_xb,wm0_xb,bc0_res,wc0_res,bm0_res,wm0_res];
columnLabels = {'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.', 'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.','Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.' };
rowLabels = {'All Countries - Actual Pop'};  
matrix2latex(ymun0_hyp, 'ymun0_hyp.tex', 'rowLabels', rowLabels, 'columnLabels', columnLabels, 'alignment', 'c', 'format', '%-6.3f', 'size', 'footnotesize');

ymun1_hyp=[bc1,wc1_y,bm1_y,wm1_y,bc1_xb,wc1_xb,bm1_xb,wm1_xb,bc1_res,wc1_res,bm1_res,wm1_res];
columnLabels = {'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.', 'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.','Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.' };
rowLabels = {'All Countries - Actual Pop'};  
matrix2latex(ymun1_hyp, 'ymun1_hyp.tex', 'rowLabels', rowLabels, 'columnLabels', columnLabels, 'alignment', 'c', 'format', '%-6.3f', 'size', 'footnotesize');

%% Geo-referenced to municipality - no US/Canada


id=ydecomp(:,1);
yj=ydecomp(:,2);
gt0_y=ydecomp(:,3);
gb0_y=ydecomp(:,4);
gw0_y=ydecomp(:,5);
gt0_xb=ydecomp(:,6);
gb0_xb=ydecomp(:,7);
gw0_xb=ydecomp(:,8);
gt0_res=ydecomp(:,9);
gb0_res=ydecomp(:,10);
gw0_res=ydecomp(:,11);
gt1_y=ydecomp(:,12);
gb1_y=ydecomp(:,13);
gw1_y=ydecomp(:,14);
gt1_xb=ydecomp(:,15);
gb1_xb=ydecomp(:,16);
gw1_xb=ydecomp(:,17);
gt1_res=ydecomp(:,18);
gb1_res=ydecomp(:,19);
gw1_res=ydecomp(:,20);
nj=ydecomp(:,21);
nj_eq=ydecomp(:,22);
yresj=ydecomp(:,23);
xbj=ydecomp(:,24);




yj=yj(id~=10 & id<=11);
gt0_y=gt0_y(id~=10 & id<=11);
gb0_y=gb0_y(id~=10 & id<=11);
gw0_y=gw0_y(id~=10 & id<=11);
gt0_xb=gt0_xb(id~=10 & id<=11);
gb0_xb=gb0_xb(id~=10 & id<=11);
gw0_xb=gw0_xb(id~=10 & id<=11);
gt0_res=gt0_res(id~=10 & id<=11);
gb0_res=gb0_res(id~=10 & id<=11);
gw0_res=gw0_res(id~=10 & id<=11);
gt1_y=gt1_y(id~=10 & id<=11);
gb1_y=gb1_y(id~=10 & id<=11);
gw1_y=gw1_y(id~=10 & id<=11);
gt1_xb=gt1_xb(id~=10 & id<=11);
gb1_xb=gb1_xb(id~=10 & id<=11);
gw1_xb=gw1_xb(id~=10 & id<=11);
gt1_res=gt1_res(id~=10 & id<=11);
gb1_res=gb1_res(id~=10 & id<=11);
gw1_res=gw1_res(id~=10 & id<=11);
nj=nj(id~=10 & id<=11);
nj_eq=nj_eq(id~=10 & id<=11);
yresj=yresj(id~=10 & id<=11);
xbj=xbj(id~=10 & id<=11);


disp('Geo-referenced to municipality; ysall Theil - assume equal population ')

njyj=nj_eq.*yj;
ny=sum(njyj);
wt=njyj./ny;
sum(wt);
wc1_y=wt.*gt1_y;
wc1_y=sum(wc1_y)
bc1=GE1munUS_hyp-wc1_y
wm1_y=wt.*gw1_y;
wm1_y=sum(wm1_y)
bm1_y=wt.*gb1_y;
bm1_y=sum(bm1_y)

disp('Geo-referenced to municipality; ysall MLD - assume equal population ')

n=sum(nj_eq);
wt=nj_eq./n;
sum(wt);;
wc0_y=wt.*gt0_y;
wc0_y=sum(wc0_y)
bc0_y=GE0munUS_hyp-wc0_y
wm0_y_y=wt.*gw0_y;
wm0_y_y=sum(wm0_y_y)
bm0_y=wt.*gb0_y;
bm0_y=sum(bm0_y)

%Geo-referenced to municipality - assume equal population 

disp('Geo-referenced to municipality; xball Theil - assume equal population ')

njyj=nj_eq.*xbj;
ny=sum(njyj);
wt=njyj./ny;
sum(wt);
wc1_xb=wt.*gt1_xb;
wc1_xb=sum(wc1_xb)
bc1_xb=GE1munUSxb_hyp-wc1_xb
wm1_xb=wt.*gw1_xb;
wm1_xb=sum(wm1_xb)
bm1_xb=wt.*gb1_xb;
bm1_xb=sum(bm1_xb)

disp('Geo-referenced to municipality; xball MLD - assume equal population ')

n=sum(nj_eq);
wt=nj_eq./n;
sum(wt);;
wc0_xb=wt.*gt0_xb;
wc0_xb=sum(wc0_xb)
bc0_xb=GE0munUSxb_hyp-wc0_xb
wm0_xb=wt.*gw0_xb;
wm0_xb=sum(wm0_xb)
bm0_xb=wt.*gb0_xb;
bm0_xb=sum(bm0_xb)

disp('Geo-referenced to municipality; yresall Theil - assume equal population ')

njyj=nj_eq.*yresj;
ny=sum(njyj);
wt=njyj./ny;
sum(wt);
wc1_res=wt.*gt1_res;
wc1_res=sum(wc1_res)
bc1_res=GE1munUSres_hyp-wc1_res
wm1_res=wt.*gw1_res;
wm1_res=sum(wm1_res)
bm1_res=wt.*gb1_res;
bm1_res=sum(bm1_res)

disp('Geo-referenced to municipality; yresall MLD - assume equal population ')

n=sum(nj_eq);
wt=nj_eq./n;
sum(wt);;
wc0_res=wt.*gt0_res;
wc0_res=sum(wc0_res)
bc0_res=GE0munUSres_hyp-wc0_res
wm0_res=wt.*gw0_res;
wm0_res=sum(wm0_res)
bm0_res=wt.*gb0_res;
bm0_res=sum(bm0_res)

ymunnoNA0_hyp=[bc0_y,wc0_y,bm0_y,wm0_y_y,bc0_xb,wc0_xb,bm0_xb,wm0_xb,bc0_res,wc0_res,bm0_res,wm0_res];
columnLabels = {'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.', 'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.','Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.' };
rowLabels = {'All Countries - Actual Pop'};  
matrix2latex(ymunnoNA0_hyp, 'ymunnoNA0_hyp.tex', 'rowLabels', rowLabels, 'columnLabels', columnLabels, 'alignment', 'c', 'format', '%-6.3f', 'size', 'footnotesize');

ymunnoNA1_hyp=[bc1,wc1_y,bm1_y,wm1_y,bc1_xb,wc1_xb,bm1_xb,wm1_xb,bc1_res,wc1_res,bm1_res,wm1_res];
columnLabels = {'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.', 'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.','Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.' };
rowLabels = {'All Countries - Actual Pop'};  
matrix2latex(ymunnoNA1_hyp, 'ymunnoNA1_hyp.tex', 'rowLabels', rowLabels, 'columnLabels', columnLabels, 'alignment', 'c', 'format', '%-6.3f', 'size', 'footnotesize');

%% Geo-referenced to region - assume equal population 

disp('Geo-referenced to region; ysall Theil - assume equal population ')

id=ydecomp(:,1);
yj=ydecomp(:,2);
gt0_y=ydecomp(:,3);
gb0_y=ydecomp(:,4);
gw0_y=ydecomp(:,5);
gt0_xb=ydecomp(:,6);
gb0_xb=ydecomp(:,7);
gw0_xb=ydecomp(:,8);
gt0_res=ydecomp(:,9);
gb0_res=ydecomp(:,10);
gw0_res=ydecomp(:,11);
gt1_y=ydecomp(:,12);
gb1_y=ydecomp(:,13);
gw1_y=ydecomp(:,14);
gt1_xb=ydecomp(:,15);
gb1_xb=ydecomp(:,16);
gw1_xb=ydecomp(:,17);
gt1_res=ydecomp(:,18);
gb1_res=ydecomp(:,19);
gw1_res=ydecomp(:,20);
nj=ydecomp(:,21);
nj_eq=ydecomp(:,22);
yresj=ydecomp(:,23);
xbj=ydecomp(:,24);




yj=yj(id>11);
gt0_y=gt0_y(id>11);
gb0_y=gb0_y(id>11);
gw0_y=gw0_y(id>11);
gt0_xb=gt0_xb(id>11);
gb0_xb=gb0_xb(id>11);
gw0_xb=gw0_xb(id>11);
gt0_res=gt0_res(id>11);
gb0_res=gb0_res(id>11);
gw0_res=gw0_res(id>11);
gt1_y=gt1_y(id>11);
gb1_y=gb1_y(id>11);
gw1_y=gw1_y(id>11);
gt1_xb=gt1_xb(id>11);
gb1_xb=gb1_xb(id>11);
gw1_xb=gw1_xb(id>11);
gt1_res=gt1_res(id>11);
gb1_res=gb1_res(id>11);
gw1_res=gw1_res(id>11);
nj=nj(id>11);
nj_eq=nj_eq(id>11);
yresj=yresj(id>11);
xbj=xbj(id>11);


njyj=nj_eq.*yj;
ny=sum(njyj);
wt=njyj./ny;
sum(wt);
wc1_y=wt.*gt1_y;
wc1_y=sum(wc1_y)
bc1=GE1reg_hyp-wc1_y
wm1_y=wt.*gw1_y;
wm1_y=sum(wm1_y)
bm1_y=wt.*gb1_y;
bm1_y=sum(bm1_y)

disp('Geo-referenced to region; ysall MLD - assume equal population ')

n=sum(nj_eq);
wt=nj_eq./n;
sum(wt);
wc0_y=wt.*gt0_y;
wc0_y=sum(wc0_y)
bc0_y=GE0reg_hyp-wc0_y
wm0_y_y=wt.*gw0_y;
wm0_y_y=sum(wm0_y_y)
bm0_y=wt.*gb0_y;
bm0_y=sum(bm0_y)

disp('Geo-referenced to region; xball Theil - assume equal population ')

njyj=nj_eq.*xbj;
ny=sum(njyj);
wt=njyj./ny;
sum(wt);
wc1_xb=wt.*gt1_xb;
wc1_xb=sum(wc1_xb)
bc1_xb=GE1regxb_hyp-wc1_xb
wm1_xb=wt.*gw1_xb;
wm1_xb=sum(wm1_xb)
bm1_xb=wt.*gb1_xb;
bm1_xb=sum(bm1_xb)

disp('Geo-referenced to region; xball MLD - assume equal population ')

n=sum(nj_eq);
wt=nj_eq./n;
sum(wt);
wc0_xb=wt.*gt0_xb;
wc0_xb=sum(wc0_xb)
bc0_xb=GE0regxb_hyp-wc0_xb
wm0_xb=wt.*gw0_xb;
wm0_xb=sum(wm0_xb)
bm0_xb=wt.*gb0_xb;
bm0_xb=sum(bm0_xb)

disp('Geo-referenced to region; yresall Theil - assume equal population ')

njyj=nj_eq.*yresj;
ny=sum(njyj);
wt=njyj./ny;
sum(wt)
wc1_res=wt.*gt1_res;
wc1_res=sum(wc1_res)
bc1_res=GE1regres_hyp-wc1_res
wm1_res=wt.*gw1_res;
wm1_res=sum(wm1_res)
bm1_res=wt.*gb1_res;
bm1_res=sum(bm1_res)


disp('Geo-referenced to region; yresall MLD - assume equal population ')

n=sum(nj_eq);
wt=nj_eq./n;
sum(wt);
wc0_res=wt.*gt0_res;
wc0_res=sum(wc0_res)
bc0_res=GE0regres_hyp-wc0_res
wm0_res=wt.*gw0_res;
wm0_res=sum(wm0_res)
bm0_res=wt.*gb0_res;
bm0_res=sum(bm0_res)

yreg0_hyp=[bc0_y,wc0_y,bm0_y,wm0_y_y,bc0_xb,wc0_xb,bm0_xb,wm0_xb,bc0_res,wc0_res,bm0_res,wm0_res];
columnLabels = {'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.', 'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.','Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.' };
rowLabels = {'All Countries - Actual Pop'};  
matrix2latex(yreg0_hyp, 'yreg0_hyp.tex', 'rowLabels', rowLabels, 'columnLabels', columnLabels, 'alignment', 'c', 'format', '%-6.3f', 'size', 'footnotesize');

yreg1_hyp=[bc1,wc1_y,bm1_y,wm1_y,bc1_xb,wc1_xb,bm1_xb,wm1_xb,bc1_res,wc1_res,bm1_res,wm1_res];
columnLabels = {'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.', 'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.','Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.' };
rowLabels = {'All Countries - Actual Pop'};  
matrix2latex(yreg1_hyp, 'yreg1_hyp.tex', 'rowLabels', rowLabels, 'columnLabels', columnLabels, 'alignment', 'c', 'format', '%-6.3f', 'size', 'footnotesize');


%% All countries less CA and US - assume equal population

disp('All countries; ysall Theil - assume equal population')

id=ydecomp(:,1);
yj=ydecomp(:,2);
gt0_y=ydecomp(:,3);
gb0_y=ydecomp(:,4);
gw0_y=ydecomp(:,5);
gt0_xb=ydecomp(:,6);
gb0_xb=ydecomp(:,7);
gw0_xb=ydecomp(:,8);
gt0_res=ydecomp(:,9);
gb0_res=ydecomp(:,10);
gw0_res=ydecomp(:,11);
gt1_y=ydecomp(:,12);
gb1_y=ydecomp(:,13);
gw1_y=ydecomp(:,14);
gt1_xb=ydecomp(:,15);
gb1_xb=ydecomp(:,16);
gw1_xb=ydecomp(:,17);
gt1_res=ydecomp(:,18);
gb1_res=ydecomp(:,19);
gw1_res=ydecomp(:,20);
nj=ydecomp(:,21);
nj_eq=ydecomp(:,22);
yresj=ydecomp(:,23);
xbj=ydecomp(:,24);




yj=yj(id~=10 & id~=12);
gt0_y=gt0_y(id~=10 & id~=12);
gb0_y=gb0_y(id~=10 & id~=12);
gw0_y=gw0_y(id~=10 & id~=12);
gt0_xb=gt0_xb(id~=10 & id~=12);
gb0_xb=gb0_xb(id~=10 & id~=12);
gw0_xb=gw0_xb(id~=10 & id~=12);
gt0_res=gt0_res(id~=10 & id~=12);
gb0_res=gb0_res(id~=10 & id~=12);
gw0_res=gw0_res(id~=10 & id~=12);
gt1_y=gt1_y(id~=10 & id~=12);
gb1_y=gb1_y(id~=10 & id~=12);
gw1_y=gw1_y(id~=10 & id~=12);
gt1_xb=gt1_xb(id~=10 & id~=12);
gb1_xb=gb1_xb(id~=10 & id~=12);
gw1_xb=gw1_xb(id~=10 & id~=12);
gt1_res=gt1_res(id~=10 & id~=12);
gb1_res=gb1_res(id~=10 & id~=12);
gw1_res=gw1_res(id~=10 & id~=12);
nj=nj(id~=10 & id~=12);
nj_eq=nj_eq(id~=10 & id~=12);
yresj=yresj(id~=10 & id~=12);
xbj=xbj(id~=10 & id~=12);


njyj=nj_eq.*yj;
ny=sum(njyj);
wt=njyj./ny;
sum(wt);
wc1_y=wt.*gt1_y;
wc1_y=sum(wc1_y)
bc1 = GE1allUS_hyp-wc1_y
wm1_y=wt.*gw1_y;
wm1_y=sum(wm1_y)
bm1_y=wt.*gb1_y;
bm1_y=sum(bm1_y)

disp('All countries; ysall MLD - assume equal population')

n=sum(nj_eq);
wt=nj_eq./n;
sum(wt);
wc0_y=wt.*gt0_y;
wc0_y=sum(wc0_y)
bc0_y= GE0allUS_hyp-wc0_y
wm0_y_y=wt.*gw0_y;
wm0_y_y=sum(wm0_y_y)
bm0_y=wt.*gb0_y;
bm0_y=sum(bm0_y)

disp('All countries; xball Theil - assume equal population')

njyj=nj_eq.*xbj;
ny=sum(njyj);
wt=njyj./ny;
sum(wt);
wc1_xb=wt.*gt1_xb;
wc1_xb=sum(wc1_xb)
bc1_xb = GE1allUSxb_hyp-wc1_xb
wm1_xb=wt.*gw1_xb;
wm1_xb=sum(wm1_xb)
bm1_xb=wt.*gb1_xb;
bm1_xb=sum(bm1_xb)

disp('All countries; xball MLD - assume equal population')

n=sum(nj_eq);
wt=nj_eq./n;
sum(wt);
wc0_xb=wt.*gt0_xb;
wc0_xb=sum(wc0_xb)
bc0_xb= GE0allUSxb_hyp-wc0_xb
wm0_xb=wt.*gw0_xb;
wm0_xb=sum(wm0_xb)
bm0_xb=wt.*gb0_xb;
bm0_xb=sum(bm0_xb)

%All countries - assume equal population

disp('All countries; yresall Theil - assume equal population')

njyj=nj_eq.*yresj;
ny=sum(njyj);
wt=njyj./ny;
sum(wt);
wc1_res=wt.*gt1_res;
wc1_res=sum(wc1_res)
bc1_res = GE1allUSres_hyp-wc1_res
wm1_res=wt.*gw1_res;
wm1_res=sum(wm1_res)
bm1_res=wt.*gb1_res;
bm1_res=sum(bm1_res)

disp('All countries; yresall MLD - assume equal population')

n=sum(nj_eq);
wt=nj_eq./n;
sum(wt);
wc0_res=wt.*gt0_res;
wc0_res=sum(wc0_res)
bc0_res= GE0allUSres_hyp-wc0_res
wm0_res=wt.*gw0_res;
wm0_res=sum(wm0_res)
bm0_res=wt.*gb0_res;
bm0_res=sum(bm0_res)

yallnoNA0_hyp=[bc0_y,wc0_y,bm0_y,wm0_y_y,bc0_xb,wc0_xb,bm0_xb,wm0_xb,bc0_res,wc0_res,bm0_res,wm0_res];
columnLabels = {'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.', 'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.','Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.' };
rowLabels = {'All Countries - Actual Pop'};  
matrix2latex(yallnoNA0_hyp, 'yallnoNA0_hyp.tex', 'rowLabels', rowLabels, 'columnLabels', columnLabels, 'alignment', 'c', 'format', '%-6.3f', 'size', 'footnotesize');

yallnoNA1_hyp=[bc1,wc1_y,bm1_y,wm1_y,bc1_xb,wc1_xb,bm1_xb,wm1_xb,bc1_res,wc1_res,bm1_res,wm1_res];
columnLabels = {'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.', 'Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.','Between Countries', 'Within Countries', 'Between Mun.', 'Within Mun.' };
rowLabels = {'All Countries - Actual Pop'};  
matrix2latex(yallnoNA1_hyp, 'yallnoNA1_hyp.tex', 'rowLabels', rowLabels, 'columnLabels', columnLabels, 'alignment', 'c', 'format', '%-6.3f', 'size', 'footnotesize');

